@@ -28,10 +28,12 @@ class Git(object):
         if ret:
             logger.error("Could not get checkout commit '%s': %s" %
                          (path, err))
-        else:
-            m = re.match(r'^commit\s*([a-z0-9]+)', out)
-            if m:
-                val = m.group(1)
+            return None
+
+        m = re.match(r'^commit\s*([a-z0-9]+)', out)
+        if m:
+            val = m.group(1)
+
         return val
 
     @classmethod
@@ -50,12 +52,16 @@ class Git(object):
 
     @classmethod
     def commit_is_ahead_of(cls, path, first, second):
-        ret1, out1, err1 = ioutils.invoke(path, ['git', 'rev-list', first])
+        # NOTE: terminate with -- to ensure the branch name is not mistaken for
+        # a path with a matching name
+        ret1, out1, err1 = ioutils.invoke(path, ['git', 'rev-list', first, '--'])
         if ret1:
             logger.error("Could not get log for branch %s for '%s': %s" %
                          (first, path, err1))
 
-        ret2, out2, err2 = ioutils.invoke(path, ['git', 'rev-list', second])
+        # NOTE: terminate with -- to ensure the branch name is not mistaken for
+        # a path with a matching name
+        ret2, out2, err2 = ioutils.invoke(path, ['git', 'rev-list', second, '--'])
         if ret2:
             logger.error("Could not get log for branch %s for '%s': %s" %
                          (second, path, err2))
@@ -141,7 +147,7 @@ class Git(object):
     @classmethod
     def get_branches_local(cls, path):
         pairs = cls._get_branches_local(path)
-        lst = map(lambda (active, name): name, pairs)
+        lst = map(lambda active_name: active_name[1], pairs)
         return lst
 
     @classmethod
@@ -226,6 +232,7 @@ class Git(object):
         ret, out, err = ioutils.invoke(path, ['git', 'merge', branch])
         if ret:
             logger.warn("Merge error using branch %s for '%s': %s" % (branch, path, err))
+            return False, out
         else:
             if out == 'Already up-to-date.':
                 out = ''
